      SUBROUTINE  read_CAMEL_coef(fn_coef, camel_qflag)
      
      
    ! Description:
    ! read the 0.05 degree resolution MEASURES CAMEL (Combined ASTER MODIS Emissivity over Land)
    ! from the netCDF file into memory. 
    ! 
    ! History:
    ! Version   Date     Comment
    ! -------   ----     -------
    !   0.6     05/11/2016  Original code E Borbas UW-Madison/CIMSS
    !   1.0     01/10/2017  Adjusted to the MEASUREs CAMEL products Version V001 (v01r02)
    !   2.0     10/09/2018  Adjusted to the MEASUREs CAMEL products Version V002 (v02r01)
    !
    ! Code Description:
    !   Language:           Fortran 90.
    !

       Implicit none
       include 'netcdf.inc'
       include 'hsriremis_EDR.inc'
       SAVE
      
    ! Define Variables.

      Integer*4 :: nvars     ! number of variables
      Integer*4 :: ndims     ! number of dimensions
      Integer*4 :: errstat   ! error code
      Integer*4 :: recdim    ! record dimension
      Integer*4 :: nc_dim(4) !  lats, lons,hng_pnt, pack_leng
      INTEGER:: gridy, gridx
      
      real :: latitude(3600)
  
      Integer    :: i,j,k,l, eline
      Integer*4 :: ncid, ngatts, nrecs, varid,varid2
           
      Integer*2 :: coeffl(nb_lons,nb_lats)      
      
      INTEGER*2, ALLOCATABLE :: sf1(:)         ! (nmask)
      INTEGER*2, ALLOCATABLE :: pc_labvs1(:)   ! (nmask)
      INTEGER*2, ALLOCATABLE :: pc_npcs1(:)    ! (nmask)
      REAL, ALLOCATABLE :: pcacoefs1(:,:)      !(wout_npcs,nmask)  
      
      Character (len=1024) :: strbuf ! string buffer for var
      Character (len=6)    :: cfld 
      Integer*4  :: indexlut

!----------------------------------------------------   	  
    ! Open netCDF file.
!----------------------------------------------------   	  
 
      errstat = nf_open(Trim(fn_coef),nf_nowrite,ncid)      

!----------------------------------------------------   	  
    ! Get info on the record dimension for this file. 
!----------------------------------------------------   	  
 
      errstat = nf_inq(ncid,ndims,nvars,ngatts,recdim)
         
      Do i=1,ndims
        errstat = nf_inq_dim(ncid,i,strbuf,nrecs)
        nc_dim(i) = nrecs
      End Do
      
      nmask=nc_dim(4)
           
!----------------------------------------------------   	  
    ! Retrieve emissivity database flag value
!----------------------------------------------------   
      errstat = nf_inq_varid (ncid, 'camel_qflag', varid)
      errstat = nf_get_var_int2(ncid,varid,coeffl)
      
       camel_qflag = coeffl
!       write(*,*) 'in read_camel_coef camel qflag=',coeffl(3905,2285), camel_qflag(3905,2285)
       instr_emis_flag = camel_qflag(gridx,gridy)
       
!----------------------------------------------------   
    ! Generate the look-up table into the emissivity data
!----------------------------------------------------   
        coef_lut = -1
       indexlut = 1
           Do i=1,nc_dim(1)
             Do j=1,nc_dim(2)
           If (camel_qflag(j,i) > 0) then
             coef_lut(j,i) = indexlut
             indexlut = indexlut + 1
           End If
         End Do
       End Do
       
!----------------------------------------------------   	  
    ! Retrieve verson number of pcs of laboratory data
!----------------------------------------------------   

       allocate(pc_labvs1(nmask))

      errstat = nf_inq_varid (ncid, 'pc_labvs', varid)
      errstat = nf_get_var_int2(ncid,varid,pc_labvs1)
      
      pc_labvs(1:nmask)=pc_labvs1

!      write(*,*) 'in read_camel_coef labvs=',pc_labvs1(coef_lut(3905,2285)),pc_labvs(coef_lut(3905,2285))

      deallocate(pc_labvs1)

!----------------------------------------------------   	  
    ! Retrieve number of PCS for each pixels
!----------------------------------------------------   

      allocate(pc_npcs1(nmask))

      errstat = nf_inq_varid (ncid, 'pc_npcs', varid)
      errstat = nf_get_var_int2(ncid,varid,pc_npcs1)
       
      pc_npcs(1:nmask)=pc_npcs1
!      write(*,*) 'in read_camel_coef npcs =',pc_npcs1(coef_lut(3905,2285)),pc_npcs(coef_lut(3905,2285))
 
      deallocate(pc_npcs1)

!----------------------------------------------------   	  
    ! Retrieve ASTER Snow Fraction
!----------------------------------------------------   	  
       allocate(sf1(nmask))
 
      errstat = nf_inq_varid (ncid, 'snow_fraction', varid)
      errstat = nf_get_var_int2(ncid,varid,sf1)
  
        snowf(1:nmask)=sf1
!       write(*,*) 'in read_camel_coef sf =',sf1(coef_lut(3905,2285)),snowf(coef_lut(3905,2285))

       deallocate(sf1)
      
!----------------------------------------------------   
   ! Retrieve coef database
!----------------------------------------------------   
       allocate(pcacoefs1(wout_npcs,nmask))
   
      errstat = nf_inq_varid (ncid,'pc_coefs',varid2)
      errstat = nf_get_var_real(ncid,varid2,pcacoefs1)
            
      !errstat = nf_get_att_real(ncid,varid,'scale_factor',pca_sfac)
      !errstat = nf_get_att_real(ncid,varid,'add_offset',pca_offs)
      !If (errstat .ne. 0)   pca_offs = 0.
      !pca_offs = 0.


       pcacoefs(:,1:nmask) = pcacoefs1
!       write(*,*) 'in read_camel_coef coef1 =',pcacoefs1(:,coef_lut(3905,2285))
!       write(*,*) 'in read_camel_coef coef =',pcacoefs(:,coef_lut(3905,2285))

      deallocate(pcacoefs1)
 
!----------------------------------------------------   
      ! closing coef file
!----------------------------------------------------   
      errstat = nf_close(ncid)


      END SUBROUTINE read_CAMEL_coef













