      program run_hsriremis

!-------------------------------------------------------------
    ! Description:
    ! program to test the software to create library to compute high spectral resolution emissivity spectra
    ! from the MEASURES CAMEL (Combined ASTER MODIS Emissivity over Land)  
    !
    ! History:
    ! Version   Date     Comment
    ! -------   ----     -------
    !  0.6       05/11/2016  Original code E Borbas UW-Madison/CIMSS
    !  1.0       01/11/2016  Adpoted for MEASURES CAMEL Version 1.0
    !
    ! Code Description:
    !   Language:           Fortran 90.
    !   Software Standards: "European Standards for Writing and
    !   Documenting Exchangeable Fortran 90 Code".
    !
    !
    !   compile bash ./run_hsriremis_oneline.mk
!-------------------------------------------------------------

       Implicit None
      
       include 'hsriremis_EDR.inc'

       Integer, Parameter :: nmonth=12
       Integer year, month
 
       Character (len=4) :: cyear
       Character (len=2) :: cmonth

       INTEGER :: err, errorstatus_fatal,errorstatus_success
       INTEGER :: i, j,ii, ios
       INTEGER:: gridy, gridx
       INTEGER :: ind1, ind2, ich, nchs
       
       REAL :: lat_site, lon_site
       REAL :: fwn,fwl
       INTEGER :: ilat, ilon

       REAL  :: hsriremis(numwave)
       
        REAL,  ALLOCATABLE :: iasi_wavenum(:)          
        REAL,  ALLOCATABLE :: instr_wavenum(:)          
        REAL,  ALLOCATABLE :: instr_emis(:)          
      
       LOGICAL :: file_exists
       LOGICAL :: instr_switch= .TRUE.
       LOGICAL :: first
       LOGICAL :: debug= .TRUE.
   
       cyear='2007'
       cmonth='01'

!          read (*,'(A)') cyear
!          read (*,'(A)') cmonth
         
!----------------------------
! Read locations
 
!    call read_profiledata
         
         ! lat_site = -24.25; lon_site = 15.25  % Namib
	 ! lat_site = -26.5; lon_site = 20.6;   % Kalahari
         ! lat_site = 21.4; lon_site = 54.3;    % Rub Al Khal
         ! lat_site = 39.11; lon_site = 83.03;  % Taklamakan
         ! lat_site = 13.65; lon_site = -9.13;  % Sahel 1
         ! lat_site = 2.44; lon_site = 13.76;   % Congo
         ! lat_site = 15.4; lon_site = -15.43;  % Dahra
         !lat_site = 19.15; lon_site = 55.57;   % Yemen Carbonate
   
         lat_site = -24.24 
	 lon_site = 15.24  ! Namib
         
	 !lat_site = 19.15 
	 !lon_site = 55.57   ! Yemen Carbonate
         
	 !lat_site = 2.44 
	 !lon_site = 13.76   ! Congo
	 
	 !lat_site= 23.579
	 !lon_site= 55.699
	 
	 !lat_site= 72.5796   ! Summit Camp - Greenland
         !lon_site= -38.4592

	 !get dimensions of lat,lon array
!----------------------------
! Read instrument cwns

        ich=0
        OPEN(333, file='iasi_chans616.txt', status='old', iostat=ios)
       
        READ(333,*,iostat=ios) ind1, ind2 , fwn, fwl
	!write(*,*)ind1, ind2 , fwn, fwl 
         Do WHILE (ios == 0 )
             ich = ich + 1
             READ(333,*,iostat=ios) ind1, ind2, fwn, fwl
	     !write(*,*)ind1, ind2 , fwn, fwl 
         ENDDO
	 rewind(333)
         CLOSE(333)
	 nchs=ich
	 write(*,*) 'nchs= ', nchs

        allocate(iasi_wavenum(nchs))
        allocate(instr_wavenum(nchs))
        allocate(instr_emis(nchs))

        OPEN(333, file='iasi_chans616.txt', status='old', iostat=ios)
        
	do i=1,nchs
	     READ(333,*,iostat=ios) ind1, ind2 , fwn, fwl
             iasi_wavenum(i) = fwn
        ENDDO
        CLOSE(333)
 	  
        instr_wavenum=iasi_wavenum
	
	do i=1,numwave
	  hsr_wavenum(i) = 698 +(i-1)*5
	  !write(*,*) i, hsr_wavenum(i)	
        enddo	  
		
!-------------------------------------------
!     calculate emissivty for the frequencies of the instrument
!
	 write(*,*) cyear,cmonth,lat_site,lon_site,prd_version
     
         first=.false.      
         ii=1
         if (ii.eq.1) first=.true.
	
	call compute_hsriremis(
     &	cyear,cmonth,lat_site,lon_site,first,instr_switch,debug,hsriremis,nchs,instr_wavenum,instr_emis)
    
!         do i=1,numwave
!	 write(*,*) hsr_wavenum(i), hsriremis(i)
!	 enddo

!-------------------------------------------
!     write out results
!
         	
        OPEN(36, file='Namib_iasi_emis.txt', status='unknown', iostat=ios)
!         OPEN(36, file='greenland_iasi_emis.txt', status='unknown', iostat=ios)
       do i=1,nchs
               write(36,*)  instr_wavenum(i), instr_emis(i)
        enddo
       close(36)
!-------------------------------------------
!     write out results
!
         	
        OPEN(37, file='Namib_hsriremis.txt', status='unknown', iostat=ios)
       do i=1,numwave
               write(37,*) hsr_wavenum(i), hsriremis(i)
        enddo
       close(37)
	
		
	 Stop
	 End
